@@ -356,8 +356,10 @@ class Language:
     INDONESIAN = "id"
     ITALIAN = "it"
     JAPANESE = "ja"
+    KOREAN = "ko"
     LITHUANIAN = "lt"
     LATVIAN = "lv"
+    NORWEGIAN = "nb"
     DUTCH = "nl"
     POLISH = "pl"
     PORTUGUESE = "pt"  # Only usable as a source language
@@ -558,28 +560,48 @@ class Translator:
             return
         elif status_code == http.HTTPStatus.FORBIDDEN:
             raise AuthorizationException(
-                f"Authorization failure, check auth_key{message}"
+                f"Authorization failure, check auth_key{message}",
+                http_status_code=status_code,
             )
         elif status_code == self._HTTP_STATUS_QUOTA_EXCEEDED:
             raise QuotaExceededException(
-                f"Quota for this billing period has been exceeded{message}"
+                f"Quota for this billing period has been exceeded{message}",
+                http_status_code=status_code,
             )
         elif status_code == http.HTTPStatus.NOT_FOUND:
             if glossary:
-                raise GlossaryNotFoundException(f"Glossary not found{message}")
-            raise DeepLException(f"Not found, check server_url{message}")
+                raise GlossaryNotFoundException(
+                    f"Glossary not found{message}",
+                    http_status_code=status_code,
+                )
+            raise DeepLException(
+                f"Not found, check server_url{message}",
+                http_status_code=status_code,
+            )
         elif status_code == http.HTTPStatus.BAD_REQUEST:
-            raise DeepLException(f"Bad request{message}")
+            raise DeepLException(
+                f"Bad request{message}", http_status_code=status_code
+            )
         elif status_code == http.HTTPStatus.TOO_MANY_REQUESTS:
             raise TooManyRequestsException(
                 "Too many requests, DeepL servers are currently experiencing "
-                f"high load{message}"
+                f"high load{message}",
+                should_retry=True,
+                http_status_code=status_code,
             )
         elif status_code == http.HTTPStatus.SERVICE_UNAVAILABLE:
             if downloading_document:
-                raise DocumentNotReadyException(f"Document not ready{message}")
+                raise DocumentNotReadyException(
+                    f"Document not ready{message}",
+                    should_retry=True,
+                    http_status_code=status_code,
+                )
             else:
-                raise DeepLException(f"Service unavailable{message}")
+                raise DeepLException(
+                    f"Service unavailable{message}",
+                    should_retry=True,
+                    http_status_code=status_code,
+                )
         else:
             status_name = (
                 http.client.responses[status_code]
@@ -588,7 +610,9 @@ class Translator:
             )
             raise DeepLException(
                 f"Unexpected status code: {status_code} {status_name}, "
-                f"content: {content}."
+                f"content: {content}.",
+                should_retry=False,
+                http_status_code=status_code,
             )
 
     def _check_valid_languages(
@@ -610,7 +634,7 @@ class Translator:
         self,
         source_lang: Union[str, Language, None],
         target_lang: Union[str, Language],
-        formality: Union[str, Formality],
+        formality: Union[str, Formality, None],
         glossary: Union[str, GlossaryInfo, None] = None,
     ) -> dict:
         # target_lang and source_lang are case insensitive
@@ -636,7 +660,7 @@ class Translator:
         request_data = {"target_lang": target_lang}
         if source_lang is not None:
             request_data["source_lang"] = source_lang
-        if str(formality).lower() != str(Formality.DEFAULT):
+        if formality is not None:
             request_data["formality"] = str(formality).lower()
         if isinstance(glossary, GlossaryInfo):
             request_data["glossary_id"] = glossary.glossary_id
@@ -687,12 +711,12 @@ class Translator:
         *,
         source_lang: Union[str, Language, None] = None,
         target_lang: Union[str, Language],
-        split_sentences: Union[str, SplitSentences] = SplitSentences.ALL,
-        preserve_formatting: bool = False,
-        formality: Union[str, Formality] = Formality.DEFAULT,
+        split_sentences: Union[str, SplitSentences, None] = None,
+        preserve_formatting: Optional[bool] = None,
+        formality: Union[str, Formality, None] = None,
         glossary: Union[str, GlossaryInfo, None] = None,
         tag_handling: Optional[str] = None,
-        outline_detection: bool = True,
+        outline_detection: Optional[bool] = None,
         non_splitting_tags: Union[str, List[str], None] = None,
         splitting_tags: Union[str, List[str], None] = None,
         ignore_tags: Union[str, List[str], None] = None,
@@ -754,14 +778,18 @@ class Translator:
         )
         request_data["text"] = text
 
-        if str(split_sentences) != str(SplitSentences.DEFAULT):
+        if split_sentences is not None:
             request_data["split_sentences"] = str(split_sentences)
-        if preserve_formatting:
-            request_data["preserve_formatting"] = "1"
+        if preserve_formatting is not None:
+            request_data["preserve_formatting"] = (
+                "1" if preserve_formatting else "0"
+            )
         if tag_handling is not None:
             request_data["tag_handling"] = tag_handling
-        if not outline_detection:
-            request_data["outline_detection"] = "0"
+        if outline_detection is not None:
+            request_data["outline_detection"] = (
+                "1" if outline_detection else "0"
+            )
 
         def join_tags(tag_argument: Union[str, Iterable[str]]) -> str:
             return (
@@ -952,7 +980,7 @@ class Translator:
         *,
         source_lang: Optional[str] = None,
         target_lang: str,
-        formality: Union[str, Formality] = Formality.DEFAULT,
+        formality: Union[str, Formality, None] = None,
         glossary: Union[str, GlossaryInfo, None] = None,
         filename: Optional[str] = None,
     ) -> DocumentHandle:
